@@ -132,10 +132,10 @@ sub gen_binary($) {
   my $hashbang = head($bin);
   if ($hashbang && $hashbang =~ /^#!\s*(\S+)/) {
     my $interpreter = $1;
-    gen_file("$interpreter:rix");
+    gen_file(realpath($interpreter) . ":rix");
     gen_elf_binary($interpreter);
   } else {
-    gen_elf_binary($bin)
+    gen_elf_binary(realpath($bin))
   }
 }
 
@@ -345,6 +345,8 @@ sub gen_change_profile($) {
 	}
     } elsif (@rules == 3) {
         push (@{$output_rules{$hat}}, "  change_profile $rules[1] -> $rules[2],\n",);
+    } elsif (@rules == 4) {
+        push (@{$output_rules{$hat}}, "  change_profile $rules[1] $rules[2] -> $rules[3],\n",);
     } else {
         (!$nowarn) && print STDERR "Warning: invalid change_profile description '$rule', ignored\n";
     }
